Styles class
Constructors
- Styles()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
getter/setter pair
-
getter/setter pair
- greenColor ↔ Color
-
getter/setter pair
-
getter/setter pair
- primaryAccentColorDark ↔ Color
-
getter/setter pair
- primaryColor ↔ Color
-
getter/setter pair
- secondaryAccentColor ↔ Color
-
getter/setter pair
- secondaryAccentColorDark ↔ Color
-
getter/setter pair
- whiteColor ↔ Color
-
getter/setter pair
- yellowColor ↔ Color
-
getter/setter pair
Constants
- blueColor → const Color
- boxBackgroundColor → const Color
- darkBackgroundColor → const Color
- errorColor → const Color
- greyColor → const Color
- primaryAccentColor → const Color
- primaryBackgroundColor → const Color
- purpleColor → const Color
- purpleColorLight → const Color
- splashBackgroundColor → const Color
- textColor → const Color
- textLightColor → const Color